@@ -9,13 +9,13 @@ Scope::Upper - Act on upper scopes.
 
 =head1 VERSION
 
-Version 0.07
+Version 0.09
 
 =cut
 
 our $VERSION;
 BEGIN {
- $VERSION = '0.07';
+ $VERSION = '0.09';
 }
 
 =head1 SYNOPSIS
@@ -72,7 +72,9 @@ BEGIN {
     sub zap {
      try {
       return @things; # returns to try() and then outside zap()
+      # not reached
      }
+     # not reached
     }
 
     my @what = zap(); # @what contains @things
@@ -115,7 +117,7 @@ BEGIN {
 
 =head2 C<reap $callback, $context>
 
-Add a destructor that calls C<$callback> when the upper scope represented by C<$context> ends.
+Add a destructor that calls C<$callback> (in void context) when the upper scope represented by C<$context> ends.
 
 =head2 C<localize $what, $value, $context>
 
@@ -189,6 +191,7 @@ This means that
     my $num = sub {
      my @a = ('a' .. 'z');
      unwind @a => HERE;
+     # not reached
     }->();
 
 will set C<$num> to C<'z'>.
@@ -203,10 +206,17 @@ The previous example can then be "corrected" :
     my $num = sub {
      my @a = ('a' .. 'z');
      unwind +(want_at(HERE) ? @a : scalar @a) => HERE;
+     # not reached
     }->();
 
 will righteously set C<$num> to C<26>.
 
+=head1 CONSTANTS
+
+=head2 C<SU_THREADSAFE>
+
+True iff the module could have been built when thread-safety features.
+
 =head1 WORDS
 
 =head2 Constants
@@ -314,6 +324,8 @@ Where L</unwind> and L</want_at> point to depending on the C<$cxt>:
 
 The functions L</reap>, L</localize>, L</localize_elem>, L</localize_delete>,  L</unwind> and L</want_at> are only exported on request, either individually or by the tags C<':funcs'> and C<':all'>.
 
+The constant L</SU_THREADSAFE> is also only exported on request, individually or by the tags C<':consts'> and C<':all'>.
+
 Same goes for the words L</TOP>, L</HERE>, L</UP>, L</SUB>, L</EVAL>, L</SCOPE> and L</CALLER> that are only exported on request, individually or by the tags C<':words'> and C<':all'>.
 
 =cut
@@ -322,8 +334,9 @@ use base qw/Exporter/;
 
 our @EXPORT      = ();
 our %EXPORT_TAGS = (
- funcs => [ qw/reap localize localize_elem localize_delete unwind want_at/ ],
- words => [ qw/TOP HERE UP SUB EVAL SCOPE CALLER/ ],
+ funcs  => [ qw/reap localize localize_elem localize_delete unwind want_at/ ],
+ words  => [ qw/TOP HERE UP SUB EVAL SCOPE CALLER/ ],
+ consts => [ qw/SU_THREADSAFE/ ],
 );
 our @EXPORT_OK   = map { @$_ } values %EXPORT_TAGS;
 $EXPORT_TAGS{'all'} = [ @EXPORT_OK ];
